@@ -24,26 +24,18 @@
 #include <string.h>
 #include <math.h>
 #include <gst/gst.h>
-#include <gst/gconf/gconf.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
 #include <glib/gi18n.h>
 
+#include "macros.h"
 #include "player.h"
 
 static void player_class_init (PlayerClass     *klass);
 static void player_init       (Player          *player);
 static void player_finalize   (GObject         *object);
-static void eos_cb            (GstElement      *sink,
-		               Player          *player);
-static void error_cb          (GstElement      *element,
-	                       GstElement      *source,
-	                       GError          *error,
-                               char            *debug,
-	                       Player          *player);
-static void state_change_cb   (GstElement      *play,
-			       GstElementState  old_state,
-		               GstElementState  new_state,
-			       Player          *player);
+static gboolean bus_message_cb (GstBus *bus,
+				GstMessage *message,
+				gpointer data);
 static gboolean tick_timeout  (Player          *player);
 
 enum {
@@ -61,7 +53,6 @@ struct _PlayerPriv {
 	int	    cur_volume;
 	double      volume_scale;
 
-	guint	    eos_idle_id;
 	guint       iterate_idle_id;
 	guint       tick_timeout_id;
 
@@ -88,6 +79,7 @@ player_get_type (void)
 				sizeof (Player),
 				0,
 				(GInstanceInitFunc) player_init,
+				NULL
 			};
 
 			type = g_type_register_static (G_TYPE_OBJECT,
@@ -137,7 +129,7 @@ player_class_init (PlayerClass *klass)
 }
 
 static void
-player_init (Player *player)
+player_init (Player *UNUSED(player))
 {
 }
 
@@ -156,7 +148,6 @@ player_construct (Player *player, char **error)
 	g_timer_stop (priv->timer);
 	priv->timer_add = 0;
 
-	priv->eos_idle_id = 0;
 	priv->tick_timeout_id = g_timeout_add (200, (GSourceFunc) tick_timeout, player);
 
 	priv->play = gst_element_factory_make ("playbin", "play");
@@ -166,7 +157,7 @@ player_construct (Player *player, char **error)
 		return;
 	}
 
-	sink = gst_gconf_get_default_audio_sink ();
+	sink = gst_element_factory_make ("gconfaudiosink", "sink");
 	if (!sink) {
 		*error = g_strdup (_("Could not render default GStreamer audio output sink"));
 
@@ -176,20 +167,8 @@ player_construct (Player *player, char **error)
 	g_object_set (G_OBJECT (priv->play), "audio-sink",
 		      sink, NULL);
 
-	g_signal_connect (priv->play,
-			  "error",
-			  G_CALLBACK (error_cb),
-			  player);
-
-	g_signal_connect (priv->play,
-			  "eos",
-			  G_CALLBACK (eos_cb),
-			  player);
-
-	g_signal_connect (priv->play,
-			  "state_change",
-			  G_CALLBACK (state_change_cb),
-			  player);
+	gst_bus_add_watch (gst_pipeline_get_bus (GST_PIPELINE (priv->play)),
+			   bus_message_cb, player);
 }
 
 static void
@@ -231,7 +210,10 @@ player_new (char **error)
 static gboolean
 tick_timeout (Player *player)
 {
-	if (gst_element_get_state (player->priv->play) != GST_STATE_PLAYING)
+	GstState state;
+
+	gst_element_get_state (player->priv->play, &state, NULL, 0);
+	if (state != GST_STATE_PLAYING)
 		return TRUE;
 
 	g_signal_emit (player, signals[TICK], 0, player_tell (player));
@@ -239,73 +221,17 @@ tick_timeout (Player *player)
 	return TRUE;
 }
 
-static gboolean
-eos_idle_cb (Player *player)
-{
-	player->priv->timer_add += floor (g_timer_elapsed (player->priv->timer, NULL) + 0.5);
-	g_timer_stop (player->priv->timer);
-	g_timer_reset (player->priv->timer);
-
-	player->priv->eos_idle_id = 0;
-
-	g_signal_emit (player, signals[END_OF_STREAM], 0);
-
-	return FALSE;
-}
-
-static void
-eos_cb (GstElement *sink, Player *player)
-{
-	player->priv->eos_idle_id = g_idle_add ((GSourceFunc) eos_idle_cb, player);
-}
-
-typedef struct {
-	Player *player;
-	char *error;
-} PlayerError;
-
-static gboolean
-error_idle_cb (PlayerError *data)
-{
-	g_signal_emit (data->player, signals[ERROR], 0, data->error);
-
-	g_free (data->error);
-	g_free (data);
-
-	return FALSE;
-}
-
-static void
-error_cb (GstElement *element,
-	  GstElement *source,
-	  GError     *error,
-          char       *debug,
-	  Player     *player)
-{
-	PlayerError *data = g_new0 (PlayerError, 1);
-
-	/* Stop playing so we don't get repeated error messages. Might lead to
-	 * troubles with threads, not sure.
-	 */
-	player_stop (player);
-
-	data->player = player;
-	data->error = g_strdup (error->message);
-
-	g_idle_add ((GSourceFunc) error_idle_cb, data);
-}
-
 static gboolean
 iterate_cb (Player *player)
 {
 	gboolean res;
+	GstState state;
 
-	if (!GST_FLAG_IS_SET (player->priv->play, GST_BIN_SELF_SCHEDULABLE)) {
-		res = gst_bin_iterate (GST_BIN (player->priv->play));
-	} else {
-		g_usleep (100);
-		res = (gst_element_get_state (player->priv->play) == GST_STATE_PLAYING);
-	}
+	g_usleep (100);
+	
+	gst_element_get_state (player->priv->play, &state, NULL, 0);
+	
+	res = (state == GST_STATE_PLAYING);
 
 	if (!res)
 		player->priv->iterate_idle_id = 0;
@@ -313,20 +239,57 @@ iterate_cb (Player *player)
 	return res;
 }
 
-static void
-state_change_cb (GstElement *play, GstElementState old_state,
-		 GstElementState new_state, Player *player)
+static gboolean
+bus_message_cb (GstBus *UNUSED(bus),
+		GstMessage *message,
+		gpointer data)
 {
-	if (old_state == GST_STATE_PLAYING) {
-		if (player->priv->iterate_idle_id != 0) {
-			g_source_remove (player->priv->iterate_idle_id);
-			player->priv->iterate_idle_id = 0;
+	Player *player = (Player *) data;
+	char *debug;
+	GError *err;
+	GstState old_state, new_state;
+
+	switch (GST_MESSAGE_TYPE (message)) {
+	case GST_MESSAGE_ERROR:
+		gst_message_parse_error (message, &err, &debug);
+
+		/* Stop playing so we don't get repeated error messages. 
+		   Might lead to troubles with threads, not sure.
+		*/
+		player_stop (player);
+		
+		g_signal_emit (player, signals[ERROR], 0, g_strdup (err->message));
+		break;
+
+	case GST_MESSAGE_EOS:
+		player->priv->timer_add += floor (g_timer_elapsed (player->priv->timer, NULL) + 0.5);
+		g_timer_stop (player->priv->timer);
+		g_timer_reset (player->priv->timer);
+		
+		g_signal_emit (player, signals[END_OF_STREAM], 0);
+		break;
+
+	case GST_MESSAGE_STATE_CHANGED:
+		gst_message_parse_state_changed (message, &old_state, &new_state, NULL);
+		
+		if (old_state == GST_STATE_PLAYING) {
+			if (player->priv->iterate_idle_id != 0) {
+				g_source_remove (player->priv->iterate_idle_id);
+				player->priv->iterate_idle_id = 0;
+			}
+		} else if (new_state == GST_STATE_PLAYING) {
+			if (player->priv->iterate_idle_id != 0)
+				g_source_remove (player->priv->iterate_idle_id);
+			player->priv->iterate_idle_id = g_idle_add ((GSourceFunc) iterate_cb, player);
 		}
-	} else if (new_state == GST_STATE_PLAYING) {
-		if (player->priv->iterate_idle_id != 0)
-			g_source_remove (player->priv->iterate_idle_id);
-		player->priv->iterate_idle_id = g_idle_add ((GSourceFunc) iterate_cb, player);
+
+		break;
+
+	default:
+		break;
 	}
+
+	return TRUE;
 }
 
 gboolean
@@ -334,8 +297,6 @@ player_set_file (Player     *player,
 		 const char *file,
 		 char      **error)
 {
-	char *escaped;
-
 	g_return_val_if_fail (IS_PLAYER (player), FALSE);
 
 	*error = NULL;
@@ -345,15 +306,17 @@ player_set_file (Player     *player,
 	if (!file)
 		return FALSE;
 
+	player->priv->current_file = gnome_vfs_get_uri_from_local_path (file);
+	if (player->priv->current_file == NULL)
+	  {
+	    *error = g_strdup ("Failed to convert filename to URI.");
+	    return FALSE;
+	  }
+
 	g_timer_stop (player->priv->timer);
 	g_timer_reset (player->priv->timer);
 	player->priv->timer_add = 0;
 
-	escaped = gnome_vfs_escape_path_string (file);
-	// FIXME get rid of this one when the switch to gnome-vfs is made
-	player->priv->current_file = g_strdup_printf ("file://%s", escaped);
-	g_free (escaped);
-
 	g_object_set (G_OBJECT (player->priv->play), "uri",
 		      player->priv->current_file, NULL);
 
@@ -375,11 +338,6 @@ player_stop (Player *player)
 {
 	g_return_if_fail (IS_PLAYER (player));
 
-	if (player->priv->eos_idle_id > 0) {
-		g_source_remove (player->priv->eos_idle_id);
-		player->priv->eos_idle_id = 0;
-	}
-
 	g_free (player->priv->current_file);
 	player->priv->current_file = NULL;
 
@@ -467,9 +425,12 @@ player_seek (Player *player, int t)
 {
 	g_return_if_fail (IS_PLAYER (player));
 
-	gst_element_seek (player->priv->play, GST_SEEK_METHOD_SET |
-		          GST_SEEK_FLAG_FLUSH | GST_FORMAT_TIME,
-		          t * GST_SECOND);
+	gst_element_seek (player->priv->play, 1.0,
+			  GST_FORMAT_TIME,
+			  GST_SEEK_FLAG_FLUSH,
+			  GST_SEEK_TYPE_SET,
+			  t * GST_SECOND,
+			  0, 0);
 
 	g_timer_reset (player->priv->timer);
 	player->priv->timer_add = t;
