@@ -25,11 +25,12 @@ using Gtk;
 
 namespace Muine
 {
-	public class HandleModel : GLib.Object, TreeModel, TreeDragSource, TreeDragDest
+	public class HandleModel
+	  : GLib.Object, TreeModel, TreeDragSource, TreeDragDest
 	{
 		// Events
 		public delegate void PlayingChangedHandler (IntPtr handle);
-		public event PlayingChangedHandler PlayingChanged;
+		public event         PlayingChangedHandler PlayingChanged;
 
 		// Delegates
 		// Delegates :: Public
@@ -57,36 +58,43 @@ namespace Muine
 
 		public static new GLib.GType GType { 
 			get {
-				IntPtr raw_ret = pointer_list_model_get_type ();
-				GLib.GType ret = new GLib.GType (raw_ret);
-				return ret;
+				IntPtr gtype_ptr = pointer_list_model_get_type ();
+				GLib.GType gtype = new GLib.GType (gtype_ptr);
+				return gtype;
 			}
 		}
 
 		// Properties :: SortFunc (set;)
 		[DllImport("libmuine")]
-		private static extern void pointer_list_model_set_sorting (IntPtr raw, CompareFuncNative sort_func);
+		private static extern void pointer_list_model_set_sorting
+		  (IntPtr raw, CompareFuncNative sort_func);
 
 		public CompareFunc SortFunc {
 			set {
-				CompareFuncWrapper wrapper = new CompareFuncWrapper (value, this);
+				CompareFuncWrapper wrapper =
+				  new CompareFuncWrapper (value, this);
+
 				pointer_list_model_set_sorting (Raw, wrapper.NativeDelegate);
 			}
 		}
 
 		// Properties :: Playing (set; get;)
 		[DllImport("libmuine")]
-		private static extern void pointer_list_model_set_current (IntPtr raw, IntPtr pointer);
+		private static extern void pointer_list_model_set_current
+		  (IntPtr raw, IntPtr pointer);
 
 		[DllImport("libmuine")]
-		private static extern IntPtr pointer_list_model_get_current (IntPtr raw);
+		private static extern IntPtr pointer_list_model_get_current
+		  (IntPtr raw);
 
 		public IntPtr Playing {
 			set {
 				pointer_list_model_set_current (Raw, value);
 
-				if (PlayingChanged != null)
-					PlayingChanged (value);
+				if (PlayingChanged == null)
+					return;
+
+				PlayingChanged (value);
 			}
 
 			get { return pointer_list_model_get_current (Raw); }
@@ -94,29 +102,56 @@ namespace Muine
 
 		// Properties :: Contents (get;)
 		[DllImport("libmuine")]
-		private static extern IntPtr pointer_list_model_get_pointers (IntPtr raw);
+		private static extern IntPtr pointer_list_model_get_pointers
+		  (IntPtr raw);
 
 		public GLib.List Contents {
 			get {
-				GLib.List ret = new GLib.List (pointer_list_model_get_pointers (Raw), typeof (int));
-				ret.Managed = true;
-				return ret;
+				IntPtr list_ptr = pointer_list_model_get_pointers (Raw);
+				Type int_type = typeof (int);
+				GLib.List list = new GLib.List (list_ptr, int_type);
+				list.Managed = true;
+
+				return list;
 			}
 		}
 
 		// Properties :: Length (get;)
 		public int Length {
-			get {
-				return IterNChildren ();
-			}
+			get { return IterNChildren (); }
+		}
+
+		// Properties :: HasFirst (get;)
+		[DllImport("libmuine")]
+		private static extern bool pointer_list_model_has_first (IntPtr raw);
+
+		public bool HasFirst {
+			get { return pointer_list_model_has_first (Raw); }
+		}
+
+		// Properties :: HasPrevious (get;)
+		[DllImport("libmuine")]
+		private static extern bool pointer_list_model_has_prev (IntPtr raw);
+
+		public bool HasPrevious {
+			get { return pointer_list_model_has_prev (Raw); }
+		}
+
+		// Properties :: HasNext (get;)
+		[DllImport("libmuine")]
+		private static extern bool pointer_list_model_has_next (IntPtr raw);
+
+		public bool HasNext {
+			get { return pointer_list_model_has_next (Raw); }
 		}
 
 		// Methods
 		// Methods :: Public
 		// Methods :: Public :: Append
 		[DllImport("libmuine")]
-		private static extern void pointer_list_model_add (IntPtr raw, IntPtr pointer);
-								     
+		private static extern void pointer_list_model_add
+		  (IntPtr raw, IntPtr pointer);
+
 		public void Append (IntPtr handle)
 		{
 			pointer_list_model_add (Raw, handle);
@@ -124,16 +159,19 @@ namespace Muine
 
 		// Methods :: Public :: Insert
 		[DllImport("libmuine")]
-		private static extern void pointer_list_model_insert (IntPtr raw, IntPtr pointer, IntPtr ins, uint pos);
+		private static extern void pointer_list_model_insert
+		  (IntPtr raw, IntPtr pointer, IntPtr ins, uint pos);
 
-		public void Insert (IntPtr handle, IntPtr ins, TreeViewDropPosition pos)
+		public void Insert
+		  (IntPtr handle, IntPtr ins, TreeViewDropPosition pos)
 		{
 			pointer_list_model_insert (Raw, handle, ins, (uint) pos);
 		}
 
 		// Methods :: Public :: Contains
 		[DllImport("libmuine")]
-		private static extern bool pointer_list_model_contains (IntPtr raw, IntPtr pointer);
+		private static extern bool pointer_list_model_contains
+		  (IntPtr raw, IntPtr pointer);
 
 		public bool Contains (IntPtr handle)
 		{
@@ -149,7 +187,8 @@ namespace Muine
 		
 		// Methods :: Public :: Remove
 		[DllImport("libmuine")]
-		private static extern void pointer_list_model_remove (IntPtr raw, IntPtr pointer);
+		private static extern void pointer_list_model_remove
+		  (IntPtr raw, IntPtr pointer);
 
 		public void Remove (IntPtr handle)
 		{
@@ -158,7 +197,8 @@ namespace Muine
 
 		// Methods :: Public :: RemoveDelta
 		[DllImport("libmuine")]
-		private static extern void pointer_list_model_remove_delta (IntPtr raw, IntPtr delta);
+		private static extern void pointer_list_model_remove_delta
+		  (IntPtr raw, IntPtr delta);
 
 		public void RemoveDelta (GLib.List delta)
 		{
@@ -175,13 +215,16 @@ namespace Muine
 			
 			pointer_list_model_clear (Raw);
 
-			if (playing_changed && PlayingChanged != null)
-				PlayingChanged (IntPtr.Zero);
+			if (playing_changed || PlayingChanged == null)
+				return;
+
+			PlayingChanged (IntPtr.Zero);
 		}
 
 		// Methods :: Public :: HandleFromIter
 		[DllImport("libmuine")]
-		private static extern IntPtr pointer_list_model_iter_get_pointer (IntPtr raw, ref TreeIter iter);
+		private static extern IntPtr pointer_list_model_iter_get_pointer
+		  (IntPtr raw, ref TreeIter iter);
 
 		public IntPtr HandleFromIter (TreeIter iter)
 		{
@@ -198,7 +241,8 @@ namespace Muine
 
 		// Methods :: Public :: IterFromHandle
 		[DllImport("libmuine")]
-		private static extern IntPtr pointer_list_model_pointer_get_iter (IntPtr raw, IntPtr pointer, out TreeIter iter);
+		private static extern IntPtr pointer_list_model_pointer_get_iter
+		  (IntPtr raw, IntPtr pointer, out TreeIter iter);
 
 		public TreeIter IterFromHandle (IntPtr handle)
 		{
@@ -215,36 +259,13 @@ namespace Muine
 
 		// Methods :: Public :: Sort
 		[DllImport("libmuine")]
-		private static extern void pointer_list_model_sort (IntPtr raw, CompareFuncNative sort_func);
+		private static extern void pointer_list_model_sort (IntPtr raw, 
+								    CompareFuncNative sort_func);
 
 		public void Sort (CompareFunc func)
 		{
 			CompareFuncWrapper wrapper = new CompareFuncWrapper (func, this);
-	                pointer_list_model_sort (Raw, wrapper.NativeDelegate);
-		}
-
-		// Methods :: Public :: HasFirst
-		[DllImport("libmuine")]
-		private static extern bool pointer_list_model_has_first (IntPtr raw);
-
-		public bool HasFirst {
-			get { return pointer_list_model_has_first (Raw); }
-		}
-
-		// Methods :: Public :: HasPrevious
-		[DllImport("libmuine")]
-		private static extern bool pointer_list_model_has_prev (IntPtr raw);
-
-		public bool HasPrevious {
-			get { return pointer_list_model_has_prev (Raw); }
-		}
-
-		// Methods :: Public :: HasNext
-		[DllImport("libmuine")]
-		private static extern bool pointer_list_model_has_next (IntPtr raw);
-
-		public bool HasNext {
-			get { return pointer_list_model_has_next (Raw); }
+			pointer_list_model_sort (Raw, wrapper.NativeDelegate);
 		}
 
 		// Methods :: Public :: First
@@ -303,7 +324,28 @@ namespace Muine
 			return ret;
 		}
 
-		// Internal fluff taken from gtk-sharp
+		// Internal Classes
+		// Internal Classes :: CompareFuncWrapper
+		internal class CompareFuncWrapper : GLib.DelegateWrapper
+		{
+			protected CompareFunc _managed;
+			internal CompareFuncNative NativeDelegate;
+
+			public int NativeCallback (IntPtr a, IntPtr b)
+			{
+				return (int) _managed (a, b);
+			}
+
+			public CompareFuncWrapper (CompareFunc managed, object o)
+			  : base (o)
+			{
+				NativeDelegate = new CompareFuncNative (NativeCallback);
+				_managed = managed;
+			}
+		}
+
+///////////////////////////// Internal fluff taken from gtk-sharp ////////////////////////////////
+
 		public void SetValue (Gtk.TreeIter iter, int column, GLib.Value value) {}
 
 		[DllImport("libgtk-2.0-0.dll")]
@@ -514,9 +556,31 @@ namespace Muine
 			gtk_tree_model_row_changed(Handle, path.Handle, ref iter);
 		}
 
-		delegate void RowsReorderedDelegate (IntPtr tree_model, IntPtr path, ref Gtk.TreeIter iter, out int new_order);
+		delegate void RowsReorderedSignalDelegate (IntPtr arg0, IntPtr arg1, ref Gtk.TreeIter arg2, out int arg3, IntPtr gch);
 
-		static RowsReorderedDelegate RowsReorderedCallback;
+		static void RowsReorderedSignalCallback (IntPtr arg0, IntPtr arg1, ref Gtk.TreeIter arg2, out int arg3, IntPtr gch)
+		{
+			GLib.Signal sig = ((GCHandle) gch).Target as GLib.Signal;
+			if (sig == null)
+				throw new Exception("Unknown signal GC handle received " + gch);
+
+			Gtk.RowsReorderedArgs args = new Gtk.RowsReorderedArgs ();
+			args.Args = new object[3];
+			if (arg1 == IntPtr.Zero)
+				args.Args[0] = null;
+			else {
+				args.Args[0] = new Gtk.TreePath(arg1);
+			}
+			args.Args[1] = arg2;
+			Gtk.RowsReorderedHandler handler = (Gtk.RowsReorderedHandler) sig.Handler;
+			handler (GLib.Object.GetObject (arg0), args);
+			arg3 = ((int)args.Args[2]);
+
+		}
+
+		delegate void RowsReorderedVMDelegate (IntPtr tree_model, IntPtr path, ref Gtk.TreeIter iter, out int new_order);
+
+		static RowsReorderedVMDelegate RowsReorderedVMCallback;
 
 		static void rowsreordered_cb (IntPtr tree_model, IntPtr path, ref Gtk.TreeIter iter, out int new_order)
 		{
@@ -526,9 +590,9 @@ namespace Muine
 
 		private static void OverrideRowsReordered (GLib.GType gtype)
 		{
-			if (RowsReorderedCallback == null)
-				RowsReorderedCallback = new RowsReorderedDelegate (rowsreordered_cb);
-			OverrideVirtualMethod (gtype, "rows_reordered", RowsReorderedCallback);
+			if (RowsReorderedVMCallback == null)
+				RowsReorderedVMCallback = new RowsReorderedVMDelegate (rowsreordered_cb);
+			OverrideVirtualMethod (gtype, "rows_reordered", RowsReorderedVMCallback);
 		}
 
 		[GLib.DefaultSignalHandler(Type=typeof(HandleModel), ConnectionMethod="OverrideRowsReordered")]
@@ -553,42 +617,39 @@ namespace Muine
 		[GLib.Signal("rows_reordered")]
 		public event Gtk.RowsReorderedHandler RowsReordered {
 			add {
-				if (value.Method.GetCustomAttributes(typeof(GLib.ConnectBeforeAttribute), false).Length > 0) {
-					if (BeforeHandlers["rows_reordered"] == null)
-						BeforeSignals["rows_reordered"] = new GtkSharp.voidObjectTreePathTreeIteroutintSignal(this, "rows_reordered", value, typeof (Gtk.RowsReorderedArgs), 0);					else
-						((GLib.SignalCallback) BeforeSignals ["rows_reordered"]).AddDelegate (value);
-					BeforeHandlers.AddHandler("rows_reordered", value);
-				} else {
-					if (AfterHandlers["rows_reordered"] == null)
-						AfterSignals["rows_reordered"] = new GtkSharp.voidObjectTreePathTreeIteroutintSignal(this, "rows_reordered", value, typeof (Gtk.RowsReorderedArgs), 1);					else
-						((GLib.SignalCallback) AfterSignals ["rows_reordered"]).AddDelegate (value);
-					AfterHandlers.AddHandler("rows_reordered", value);
-				}
+				GLib.Signal sig = GLib.Signal.Lookup (this, "rows_reordered", new RowsReorderedSignalDelegate(RowsReorderedSignalCallback));
+				sig.AddDelegate (value);
 			}
 			remove {
-				System.ComponentModel.EventHandlerList event_list = AfterHandlers;
-				Hashtable signals = AfterSignals;
-				if (value.Method.GetCustomAttributes(typeof(GLib.ConnectBeforeAttribute), false).Length > 0) {
-					event_list = BeforeHandlers;
-					signals = BeforeSignals;
-				}
-				GLib.SignalCallback cb = signals ["rows_reordered"] as GLib.SignalCallback;
-				event_list.RemoveHandler("rows_reordered", value);
-				if (cb == null)
-					return;
-
-				cb.RemoveDelegate (value);
-
-				if (event_list["rows_reordered"] == null) {
-					signals.Remove("rows_reordered");
-					cb.Dispose ();
-				}
+				GLib.Signal sig = GLib.Signal.Lookup (this, "rows_reordered", new RowsReorderedSignalDelegate(RowsReorderedSignalCallback));
+				sig.RemoveDelegate (value);
 			}
 		}
 
-		delegate void RowChangedDelegate (IntPtr tree_model, IntPtr path, ref Gtk.TreeIter iter);
+		delegate void RowChangedSignalDelegate (IntPtr arg0, IntPtr arg1, ref Gtk.TreeIter arg2, IntPtr gch);
 
-		static RowChangedDelegate RowChangedCallback;
+		static void RowChangedSignalCallback (IntPtr arg0, IntPtr arg1, ref Gtk.TreeIter arg2, IntPtr gch)
+		{
+			GLib.Signal sig = ((GCHandle) gch).Target as GLib.Signal;
+			if (sig == null)
+				throw new Exception("Unknown signal GC handle received " + gch);
+
+			Gtk.RowChangedArgs args = new Gtk.RowChangedArgs ();
+			args.Args = new object[2];
+			if (arg1 == IntPtr.Zero)
+				args.Args[0] = null;
+			else {
+				args.Args[0] = new Gtk.TreePath(arg1);
+			}
+			args.Args[1] = arg2;
+			Gtk.RowChangedHandler handler = (Gtk.RowChangedHandler) sig.Handler;
+			handler (GLib.Object.GetObject (arg0), args);
+
+		}
+
+		delegate void RowChangedVMDelegate (IntPtr tree_model, IntPtr path, ref Gtk.TreeIter iter);
+
+		static RowChangedVMDelegate RowChangedVMCallback;
 
 		static void rowchanged_cb (IntPtr tree_model, IntPtr path, ref Gtk.TreeIter iter)
 		{
@@ -598,9 +659,9 @@ namespace Muine
 
 		private static void OverrideRowChanged (GLib.GType gtype)
 		{
-			if (RowChangedCallback == null)
-				RowChangedCallback = new RowChangedDelegate (rowchanged_cb);
-			OverrideVirtualMethod (gtype, "row_changed", RowChangedCallback);
+			if (RowChangedVMCallback == null)
+				RowChangedVMCallback = new RowChangedVMDelegate (rowchanged_cb);
+			OverrideVirtualMethod (gtype, "row_changed", RowChangedVMCallback);
 		}
 
 		[GLib.DefaultSignalHandler(Type=typeof(HandleModel), ConnectionMethod="OverrideRowChanged")]
@@ -621,42 +682,38 @@ namespace Muine
 		[GLib.Signal("row_changed")]
 		public event Gtk.RowChangedHandler RowChanged {
 			add {
-				if (value.Method.GetCustomAttributes(typeof(GLib.ConnectBeforeAttribute), false).Length > 0) {
-					if (BeforeHandlers["row_changed"] == null)
-						BeforeSignals["row_changed"] = new GtkSharp.voidObjectTreePathTreeIterSignal(this, "row_changed", value, typeof (Gtk.RowChangedArgs), 0);					else
-						((GLib.SignalCallback) BeforeSignals ["row_changed"]).AddDelegate (value);
-					BeforeHandlers.AddHandler("row_changed", value);
-				} else {
-					if (AfterHandlers["row_changed"] == null)
-						AfterSignals["row_changed"] = new GtkSharp.voidObjectTreePathTreeIterSignal(this, "row_changed", value, typeof (Gtk.RowChangedArgs), 1);					else
-						((GLib.SignalCallback) AfterSignals ["row_changed"]).AddDelegate (value);
-					AfterHandlers.AddHandler("row_changed", value);
-				}
+				GLib.Signal sig = GLib.Signal.Lookup (this, "row_changed", new RowChangedSignalDelegate(RowChangedSignalCallback));
+				sig.AddDelegate (value);
 			}
 			remove {
-				System.ComponentModel.EventHandlerList event_list = AfterHandlers;
-				Hashtable signals = AfterSignals;
-				if (value.Method.GetCustomAttributes(typeof(GLib.ConnectBeforeAttribute), false).Length > 0) {
-					event_list = BeforeHandlers;
-					signals = BeforeSignals;
-				}
-				GLib.SignalCallback cb = signals ["row_changed"] as GLib.SignalCallback;
-				event_list.RemoveHandler("row_changed", value);
-				if (cb == null)
-					return;
-
-				cb.RemoveDelegate (value);
-
-				if (event_list["row_changed"] == null) {
-					signals.Remove("row_changed");
-					cb.Dispose ();
-				}
+				GLib.Signal sig = GLib.Signal.Lookup (this, "row_changed", new RowChangedSignalDelegate(RowChangedSignalCallback));
+				sig.RemoveDelegate (value);
 			}
 		}
 
-		delegate void RowDeletedDelegate (IntPtr tree_model, IntPtr path);
+			delegate void RowDeletedSignalDelegate (IntPtr arg0, IntPtr arg1, IntPtr gch);
 
-		static RowDeletedDelegate RowDeletedCallback;
+		static void RowDeletedSignalCallback (IntPtr arg0, IntPtr arg1, IntPtr gch)
+		{
+			GLib.Signal sig = ((GCHandle) gch).Target as GLib.Signal;
+			if (sig == null)
+				throw new Exception("Unknown signal GC handle received " + gch);
+
+			Gtk.RowDeletedArgs args = new Gtk.RowDeletedArgs ();
+			args.Args = new object[1];
+			if (arg1 == IntPtr.Zero)
+				args.Args[0] = null;
+			else {
+				args.Args[0] = new Gtk.TreePath(arg1);
+			}
+			Gtk.RowDeletedHandler handler = (Gtk.RowDeletedHandler) sig.Handler;
+			handler (GLib.Object.GetObject (arg0), args);
+
+		}
+
+		delegate void RowDeletedVMDelegate (IntPtr tree_model, IntPtr path);
+
+		static RowDeletedVMDelegate RowDeletedVMCallback;
 
 		static void rowdeleted_cb (IntPtr tree_model, IntPtr path)
 		{
@@ -666,9 +723,9 @@ namespace Muine
 
 		private static void OverrideRowDeleted (GLib.GType gtype)
 		{
-			if (RowDeletedCallback == null)
-				RowDeletedCallback = new RowDeletedDelegate (rowdeleted_cb);
-			OverrideVirtualMethod (gtype, "row_deleted", RowDeletedCallback);
+			if (RowDeletedVMCallback == null)
+				RowDeletedVMCallback = new RowDeletedVMDelegate (rowdeleted_cb);
+			OverrideVirtualMethod (gtype, "row_deleted", RowDeletedVMCallback);
 		}
 
 		[GLib.DefaultSignalHandler(Type=typeof(HandleModel), ConnectionMethod="OverrideRowDeleted")]
@@ -687,42 +744,39 @@ namespace Muine
 		[GLib.Signal("row_deleted")]
 		public event Gtk.RowDeletedHandler RowDeleted {
 			add {
-				if (value.Method.GetCustomAttributes(typeof(GLib.ConnectBeforeAttribute), false).Length > 0) {
-					if (BeforeHandlers["row_deleted"] == null)
-						BeforeSignals["row_deleted"] = new GtkSharp.voidObjectTreePathSignal(this, "row_deleted", value, typeof (Gtk.RowDeletedArgs), 0);					else
-						((GLib.SignalCallback) BeforeSignals ["row_deleted"]).AddDelegate (value);
-					BeforeHandlers.AddHandler("row_deleted", value);
-				} else {
-					if (AfterHandlers["row_deleted"] == null)
-						AfterSignals["row_deleted"] = new GtkSharp.voidObjectTreePathSignal(this, "row_deleted", value, typeof (Gtk.RowDeletedArgs), 1);					else
-						((GLib.SignalCallback) AfterSignals ["row_deleted"]).AddDelegate (value);
-					AfterHandlers.AddHandler("row_deleted", value);
-				}
+				GLib.Signal sig = GLib.Signal.Lookup (this, "row_deleted", new RowDeletedSignalDelegate(RowDeletedSignalCallback));
+				sig.AddDelegate (value);
 			}
 			remove {
-				System.ComponentModel.EventHandlerList event_list = AfterHandlers;
-				Hashtable signals = AfterSignals;
-				if (value.Method.GetCustomAttributes(typeof(GLib.ConnectBeforeAttribute), false).Length > 0) {
-					event_list = BeforeHandlers;
-					signals = BeforeSignals;
-				}
-				GLib.SignalCallback cb = signals ["row_deleted"] as GLib.SignalCallback;
-				event_list.RemoveHandler("row_deleted", value);
-				if (cb == null)
-					return;
-
-				cb.RemoveDelegate (value);
-
-				if (event_list["row_deleted"] == null) {
-					signals.Remove("row_deleted");
-					cb.Dispose ();
-				}
+				GLib.Signal sig = GLib.Signal.Lookup (this, "row_deleted", new RowDeletedSignalDelegate(RowDeletedSignalCallback));
+				sig.RemoveDelegate (value);
 			}
 		}
 
-		delegate void RowInsertedDelegate (IntPtr tree_model, IntPtr path, ref Gtk.TreeIter iter);
+		delegate void RowInsertedSignalDelegate (IntPtr arg0, IntPtr arg1, ref Gtk.TreeIter arg2, IntPtr gch);
 
-		static RowInsertedDelegate RowInsertedCallback;
+		static void RowInsertedSignalCallback (IntPtr arg0, IntPtr arg1, ref Gtk.TreeIter arg2, IntPtr gch)
+		{
+			GLib.Signal sig = ((GCHandle) gch).Target as GLib.Signal;
+			if (sig == null)
+				throw new Exception("Unknown signal GC handle received " + gch);
+
+			Gtk.RowInsertedArgs args = new Gtk.RowInsertedArgs ();
+			args.Args = new object[2];
+			if (arg1 == IntPtr.Zero)
+				args.Args[0] = null;
+			else {
+				args.Args[0] = new Gtk.TreePath(arg1);
+			}
+			args.Args[1] = arg2;
+			Gtk.RowInsertedHandler handler = (Gtk.RowInsertedHandler) sig.Handler;
+			handler (GLib.Object.GetObject (arg0), args);
+
+		}
+
+		delegate void RowInsertedVMDelegate (IntPtr tree_model, IntPtr path, ref Gtk.TreeIter iter);
+
+		static RowInsertedVMDelegate RowInsertedVMCallback;
 
 		static void rowinserted_cb (IntPtr tree_model, IntPtr path, ref Gtk.TreeIter iter)
 		{
@@ -732,9 +786,9 @@ namespace Muine
 
 		private static void OverrideRowInserted (GLib.GType gtype)
 		{
-			if (RowInsertedCallback == null)
-				RowInsertedCallback = new RowInsertedDelegate (rowinserted_cb);
-			OverrideVirtualMethod (gtype, "row_inserted", RowInsertedCallback);
+			if (RowInsertedVMCallback == null)
+				RowInsertedVMCallback = new RowInsertedVMDelegate (rowinserted_cb);
+			OverrideVirtualMethod (gtype, "row_inserted", RowInsertedVMCallback);
 		}
 
 		[GLib.DefaultSignalHandler(Type=typeof(HandleModel), ConnectionMethod="OverrideRowInserted")]
@@ -755,42 +809,39 @@ namespace Muine
 		[GLib.Signal("row_inserted")]
 		public event Gtk.RowInsertedHandler RowInserted {
 			add {
-				if (value.Method.GetCustomAttributes(typeof(GLib.ConnectBeforeAttribute), false).Length > 0) {
-					if (BeforeHandlers["row_inserted"] == null)
-						BeforeSignals["row_inserted"] = new GtkSharp.voidObjectTreePathTreeIterSignal(this, "row_inserted", value, typeof (Gtk.RowInsertedArgs), 0);					else
-						((GLib.SignalCallback) BeforeSignals ["row_inserted"]).AddDelegate (value);
-					BeforeHandlers.AddHandler("row_inserted", value);
-				} else {
-					if (AfterHandlers["row_inserted"] == null)
-						AfterSignals["row_inserted"] = new GtkSharp.voidObjectTreePathTreeIterSignal(this, "row_inserted", value, typeof (Gtk.RowInsertedArgs), 1);					else
-						((GLib.SignalCallback) AfterSignals ["row_inserted"]).AddDelegate (value);
-					AfterHandlers.AddHandler("row_inserted", value);
-				}
+				GLib.Signal sig = GLib.Signal.Lookup (this, "row_inserted", new RowInsertedSignalDelegate(RowInsertedSignalCallback));
+				sig.AddDelegate (value);
 			}
 			remove {
-				System.ComponentModel.EventHandlerList event_list = AfterHandlers;
-				Hashtable signals = AfterSignals;
-				if (value.Method.GetCustomAttributes(typeof(GLib.ConnectBeforeAttribute), false).Length > 0) {
-					event_list = BeforeHandlers;
-					signals = BeforeSignals;
-				}
-				GLib.SignalCallback cb = signals ["row_inserted"] as GLib.SignalCallback;
-				event_list.RemoveHandler("row_inserted", value);
-				if (cb == null)
-					return;
-
-				cb.RemoveDelegate (value);
-
-				if (event_list["row_inserted"] == null) {
-					signals.Remove("row_inserted");
-					cb.Dispose ();
-				}
+				GLib.Signal sig = GLib.Signal.Lookup (this, "row_inserted", new RowInsertedSignalDelegate(RowInsertedSignalCallback));
+				sig.RemoveDelegate (value);
 			}
 		}
 
-		delegate void RowHasChildToggledDelegate (IntPtr tree_model, IntPtr path, ref Gtk.TreeIter iter);
+		delegate void RowHasChildToggledSignalDelegate (IntPtr arg0, IntPtr arg1, ref Gtk.TreeIter arg2, IntPtr gch);
 
-		static RowHasChildToggledDelegate RowHasChildToggledCallback;
+		static void RowHasChildToggledSignalCallback (IntPtr arg0, IntPtr arg1, ref Gtk.TreeIter arg2, IntPtr gch)
+		{
+			GLib.Signal sig = ((GCHandle) gch).Target as GLib.Signal;
+			if (sig == null)
+				throw new Exception("Unknown signal GC handle received " + gch);
+
+			Gtk.RowHasChildToggledArgs args = new Gtk.RowHasChildToggledArgs ();
+			args.Args = new object[2];
+			if (arg1 == IntPtr.Zero)
+				args.Args[0] = null;
+			else {
+				args.Args[0] = new Gtk.TreePath(arg1);
+			}
+			args.Args[1] = arg2;
+			Gtk.RowHasChildToggledHandler handler = (Gtk.RowHasChildToggledHandler) sig.Handler;
+			handler (GLib.Object.GetObject (arg0), args);
+
+		}
+
+		delegate void RowHasChildToggledVMDelegate (IntPtr tree_model, IntPtr path, ref Gtk.TreeIter iter);
+
+		static RowHasChildToggledVMDelegate RowHasChildToggledVMCallback;
 
 		static void rowhaschildtoggled_cb (IntPtr tree_model, IntPtr path, ref Gtk.TreeIter iter)
 		{
@@ -800,9 +851,9 @@ namespace Muine
 
 		private static void OverrideRowHasChildToggled (GLib.GType gtype)
 		{
-			if (RowHasChildToggledCallback == null)
-				RowHasChildToggledCallback = new RowHasChildToggledDelegate (rowhaschildtoggled_cb);
-			OverrideVirtualMethod (gtype, "row_has_child_toggled", RowHasChildToggledCallback);
+			if (RowHasChildToggledVMCallback == null)
+				RowHasChildToggledVMCallback = new RowHasChildToggledVMDelegate (rowhaschildtoggled_cb);
+			OverrideVirtualMethod (gtype, "row_has_child_toggled", RowHasChildToggledVMCallback);
 		}
 
 		[GLib.DefaultSignalHandler(Type=typeof(HandleModel), ConnectionMethod="OverrideRowHasChildToggled")]
@@ -823,36 +874,12 @@ namespace Muine
 		[GLib.Signal("row_has_child_toggled")]
 		public event Gtk.RowHasChildToggledHandler RowHasChildToggled {
 			add {
-				if (value.Method.GetCustomAttributes(typeof(GLib.ConnectBeforeAttribute), false).Length > 0) {
-					if (BeforeHandlers["row_has_child_toggled"] == null)
-						BeforeSignals["row_has_child_toggled"] = new GtkSharp.voidObjectTreePathTreeIterSignal(this, "row_has_child_toggled", value, typeof (Gtk.RowHasChildToggledArgs), 0);					else
-						((GLib.SignalCallback) BeforeSignals ["row_has_child_toggled"]).AddDelegate (value);
-					BeforeHandlers.AddHandler("row_has_child_toggled", value);
-				} else {
-					if (AfterHandlers["row_has_child_toggled"] == null)
-						AfterSignals["row_has_child_toggled"] = new GtkSharp.voidObjectTreePathTreeIterSignal(this, "row_has_child_toggled", value, typeof (Gtk.RowHasChildToggledArgs), 1);					else
-						((GLib.SignalCallback) AfterSignals ["row_has_child_toggled"]).AddDelegate (value);
-					AfterHandlers.AddHandler("row_has_child_toggled", value);
-				}
+				GLib.Signal sig = GLib.Signal.Lookup (this, "row_has_child_toggled", new RowHasChildToggledSignalDelegate(RowHasChildToggledSignalCallback));
+				sig.AddDelegate (value);
 			}
 			remove {
-				System.ComponentModel.EventHandlerList event_list = AfterHandlers;
-				Hashtable signals = AfterSignals;
-				if (value.Method.GetCustomAttributes(typeof(GLib.ConnectBeforeAttribute), false).Length > 0) {
-					event_list = BeforeHandlers;
-					signals = BeforeSignals;
-				}
-				GLib.SignalCallback cb = signals ["row_has_child_toggled"] as GLib.SignalCallback;
-				event_list.RemoveHandler("row_has_child_toggled", value);
-				if (cb == null)
-					return;
-
-				cb.RemoveDelegate (value);
-
-				if (event_list["row_has_child_toggled"] == null) {
-					signals.Remove("row_has_child_toggled");
-					cb.Dispose ();
-				}
+				GLib.Signal sig = GLib.Signal.Lookup (this, "row_has_child_toggled", new RowHasChildToggledSignalDelegate(RowHasChildToggledSignalCallback));
+				sig.RemoveDelegate (value);
 			}
 		}
 
@@ -962,35 +989,15 @@ namespace Muine
 			val.Dispose ();
 			return ret;
 		}
-
-		// Internal Classes
-		// Internal Classes :: CompareFuncWrapper
-		internal class CompareFuncWrapper : GLib.DelegateWrapper
-		{
-			protected CompareFunc _managed;
-			internal CompareFuncNative NativeDelegate;
-
-			public int NativeCallback (IntPtr a, IntPtr b)
-			{
-				return (int) _managed (a, b);
-			}
-
-			public CompareFuncWrapper (CompareFunc managed, object o) : base (o)
-			{
-				NativeDelegate = new CompareFuncNative (NativeCallback);
-				_managed = managed;
-			}
-		}
 	}
 }
 
 namespace GtkSharp
 {
-	using System;
-
 	internal delegate bool TreeModelForeachFuncNative(IntPtr model, IntPtr path, ref Gtk.TreeIter iter, IntPtr data);
 
 	internal class TreeModelForeachFuncWrapper : GLib.DelegateWrapper {
+
 		public bool NativeCallback (IntPtr model, IntPtr path, ref Gtk.TreeIter iter, IntPtr data)
 		{
 			Gtk.TreeModel _arg0 = (Gtk.TreeModel) GLib.Object.GetObject(model);
@@ -1008,139 +1015,4 @@ namespace GtkSharp
 			_managed = managed;
 		}
 	}
-
-	internal delegate void voidObjectTreePathTreeIterDelegate(IntPtr arg0, IntPtr arg1, ref Gtk.TreeIter arg2, int key);
-
-	internal class voidObjectTreePathTreeIterSignal : GLib.SignalCallback {
-
-		private static voidObjectTreePathTreeIterDelegate _Delegate;
-
-		private static void voidObjectTreePathTreeIterCallback(IntPtr arg0, IntPtr arg1, ref Gtk.TreeIter arg2, int key)
-		{
-			if (!_Instances.Contains(key))
-				throw new Exception("Unexpected signal key " + key);
-
-			voidObjectTreePathTreeIterSignal inst = (voidObjectTreePathTreeIterSignal) _Instances[key];
-			GLib.SignalArgs args = (GLib.SignalArgs) Activator.CreateInstance (inst._argstype);
-			args.Args = new object[2];
-			if (arg1 == IntPtr.Zero)
-				args.Args[0] = null;
-			else {
-				args.Args[0] = new Gtk.TreePath(arg1);
-			}
-			args.Args[1] = arg2;
-			object[] argv = new object[2];
-			argv[0] = inst._obj;
-			argv[1] = args;
-			inst._handler.DynamicInvoke(argv);
-		}
-
-		public voidObjectTreePathTreeIterSignal(GLib.Object obj, string name, Delegate eh, Type argstype, int connect_flags) : base(obj, eh, argstype)
-		{
-			if (_Delegate == null) {
-				_Delegate = new voidObjectTreePathTreeIterDelegate(voidObjectTreePathTreeIterCallback);
-			}
-			Connect (name, _Delegate, connect_flags);
-		}
-
-		protected override void Dispose (bool disposing)
-		{
-			_Instances.Remove(_key);
-			if(_Instances.Count == 0)
-				_Delegate = null;
-
-			Disconnect ();
-			base.Dispose (disposing);
-		}
-	}
-	
-	internal delegate void voidObjectTreePathDelegate(IntPtr arg0, IntPtr arg1, int key);
-
-	internal class voidObjectTreePathSignal : GLib.SignalCallback {
-
-		private static voidObjectTreePathDelegate _Delegate;
-
-		private static void voidObjectTreePathCallback(IntPtr arg0, IntPtr arg1, int key)
-		{
-			if (!_Instances.Contains(key))
-				throw new Exception("Unexpected signal key " + key);
-
-			voidObjectTreePathSignal inst = (voidObjectTreePathSignal) _Instances[key];
-			GLib.SignalArgs args = (GLib.SignalArgs) Activator.CreateInstance (inst._argstype);
-			args.Args = new object[1];
-			if (arg1 == IntPtr.Zero)
-				args.Args[0] = null;
-			else {
-				args.Args[0] = new Gtk.TreePath(arg1);
-			}
-			object[] argv = new object[2];
-			argv[0] = inst._obj;
-			argv[1] = args;
-			inst._handler.DynamicInvoke(argv);
-		}
-
-		public voidObjectTreePathSignal(GLib.Object obj, string name, Delegate eh, Type argstype, int connect_flags) : base(obj, eh, argstype)
-		{
-			if (_Delegate == null) {
-				_Delegate = new voidObjectTreePathDelegate(voidObjectTreePathCallback);
-			}
-			Connect (name, _Delegate, connect_flags);
-		}
-
-		protected override void Dispose (bool disposing)
-		{
-			_Instances.Remove(_key);
-			if(_Instances.Count == 0)
-				_Delegate = null;
-
-			Disconnect ();
-			base.Dispose (disposing);
-		}
-	}
-
-	internal delegate void voidObjectTreePathTreeIteroutintDelegate(IntPtr arg0, IntPtr arg1, ref Gtk.TreeIter arg2, out int arg3, int key);
-
-	internal class voidObjectTreePathTreeIteroutintSignal : GLib.SignalCallback {
-
-		private static voidObjectTreePathTreeIteroutintDelegate _Delegate;
-
-		private static void voidObjectTreePathTreeIteroutintCallback(IntPtr arg0, IntPtr arg1, ref Gtk.TreeIter arg2, out int arg3, int key)
-		{
-			if (!_Instances.Contains(key))
-				throw new Exception("Unexpected signal key " + key);
-
-			voidObjectTreePathTreeIteroutintSignal inst = (voidObjectTreePathTreeIteroutintSignal) _Instances[key];
-			GLib.SignalArgs args = (GLib.SignalArgs) Activator.CreateInstance (inst._argstype);
-			args.Args = new object[3];
-			if (arg1 == IntPtr.Zero)
-				args.Args[0] = null;
-			else {
-				args.Args[0] = new Gtk.TreePath(arg1);
-			}
-			args.Args[1] = arg2;
-			object[] argv = new object[2];
-			argv[0] = inst._obj;
-			argv[1] = args;
-			inst._handler.DynamicInvoke(argv);
-			arg3 = ((int)args.Args[2]);
-		}
-
-		public voidObjectTreePathTreeIteroutintSignal(GLib.Object obj, string name, Delegate eh, Type argstype, int connect_flags) : base(obj, eh, argstype)
-		{
-			if (_Delegate == null) {
-				_Delegate = new voidObjectTreePathTreeIteroutintDelegate(voidObjectTreePathTreeIteroutintCallback);
-			}
-			Connect (name, _Delegate, connect_flags);
-		}
-
-		protected override void Dispose (bool disposing)
-		{
-			_Instances.Remove(_key);
-			if(_Instances.Count == 0)
-				_Delegate = null;
-
-			Disconnect ();
-			base.Dispose (disposing);
-		}
-	}
 }
